@@ -144,7 +144,8 @@ class FilterProperMovies(object):
                 fire_event('forget', entry['imdb_id'])
                 entry.accept('proper version of previously downloaded movie')
 
-    def on_task_exit(self, task, config):
+    @plugin.priority(-255)
+    def on_task_output(self, task, config):
         """Add downloaded movies to the database"""
         log.debug('check for learning')
         for entry in task.accepted:
